@@ -1,17 +1,30 @@
 #!/usr/bin/env python
 # -*- coding:utf-8 -*-
 # @Author: Jialiang Shi
-from gerrit.utils.models import BaseModel
+from gerrit.utils.gerritbase import GerritBase
 from gerrit.accounts.emails import GerritAccountEmails
 from gerrit.accounts.ssh_keys import GerritAccountSSHKeys
 from gerrit.accounts.gpg_keys import GerritAccountGPGKeys
 
 
-class GerritAccount(BaseModel):
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-        self.entity_name = "username"
-        self.endpoint = f"/accounts/{self.username}"
+class GerritAccount(GerritBase):
+    def __init__(self, account, gerrit):
+        self.account = account
+        self.gerrit = gerrit
+        self.endpoint = f"/accounts/{self.account}"
+        GerritBase.__init__(self)
+
+    def __str__(self):
+        return str(self.account)
+
+    def get_detail(self):
+        """
+        fetch account info in more details, such as: registered_on
+
+        :return:
+        """
+        result = self.gerrit.get(self.endpoint + "/detail")
+        return result
 
     def get_name(self):
         """
@@ -38,8 +51,7 @@ class GerritAccount(BaseModel):
 
 
         :param input_: the AccountNameInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #account-name-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#account-name-input
         :return:
         """
         return self.gerrit.put(self.endpoint + "/name",
@@ -94,8 +106,7 @@ class GerritAccount(BaseModel):
             result = account.set_username(input_)
 
         :param input_: the UsernameInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #username-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#username-input
         :return:
         """
         return self.gerrit.put(self.endpoint + "/username",
@@ -116,8 +127,7 @@ class GerritAccount(BaseModel):
             result = account.set_displayname(input_)
 
         :param input_: the DisplayNameInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #display-name-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#display-name-input
         :return:
         """
         return self.gerrit.put(self.endpoint + "/displayname",
@@ -163,8 +173,7 @@ class GerritAccount(BaseModel):
             result = account.set_http_password(input_)
 
         :param input_: the HttpPasswordInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #http-password-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#http-password-input
         :return:
         """
         return self.gerrit.put(self.endpoint + "/password.http",
@@ -191,15 +200,15 @@ class GerritAccount(BaseModel):
 
     @property
     def emails(self):
-        return GerritAccountEmails(username=self.username, gerrit=self.gerrit)
+        return GerritAccountEmails(account=self.account, gerrit=self.gerrit)
 
     @property
     def ssh_keys(self):
-        return GerritAccountSSHKeys(username=self.username, gerrit=self.gerrit)
+        return GerritAccountSSHKeys(account=self.account, gerrit=self.gerrit)
 
     @property
     def gpg_keys(self):
-        return GerritAccountGPGKeys(username=self.username, gerrit=self.gerrit)
+        return GerritAccountGPGKeys(account=self.account, gerrit=self.gerrit)
 
     def list_capabilities(self):
         """
@@ -276,8 +285,7 @@ class GerritAccount(BaseModel):
             result = account.set_user_preferences(input_)
 
         :param input_: the PreferencesInput entity，
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #preferences-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#preferences-input
         :return:
         """
         return self.gerrit.put(self.endpoint + "/preferences",
@@ -316,8 +324,7 @@ class GerritAccount(BaseModel):
             result = account.set_diff_preferences(input_)
 
         :param input_: the DiffPreferencesInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #diff-preferences-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#diff-preferences-input
         :return:
         """
         return self.gerrit.put(self.endpoint + "/preferences.diff",
@@ -358,8 +365,7 @@ class GerritAccount(BaseModel):
             result = account.set_edit_preferences(input_)
 
         :param input_: the EditPreferencesInfo entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #edit-preferences-info
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#edit-preferences-info
         :return:
         """
         return self.gerrit.put(self.endpoint + "/preferences.edit",
@@ -473,14 +479,12 @@ class GerritAccount(BaseModel):
             result = account.sign_contributor_agreement(input_)
 
         :param input_: the ContributorAgreementInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #contributor-agreement-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#contributor-agreement-input
         :return:
         """
         return self.gerrit.put(self.endpoint + "/agreements",
                                json=input_, headers=self.gerrit.default_headers)
 
-
     def delete_draft_comments(self, input_):
         """
         Deletes some or all of a user’s draft comments.
@@ -494,8 +498,7 @@ class GerritAccount(BaseModel):
             result = account.delete_draft_comments(input_)
 
         :param input_: the DeleteDraftCommentsInput entity,
-          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html
-          #delete-draft-comments-input
+          https://gerrit-review.googlesource.com/Documentation/rest-api-accounts.html#delete-draft-comments-input
         :return:
         """
         return self.gerrit.post(self.endpoint + "/drafts:delete",
@@ -516,7 +519,7 @@ class GerritAccount(BaseModel):
         :return:
         """
         result = self.gerrit.get(self.endpoint + "/starred.changes")
-        return [self.gerrit.changes.get(item.get("id")) for item in result]
+        return result
 
     def put_default_star_on_change(self, id_):
         """
@@ -543,7 +546,7 @@ class GerritAccount(BaseModel):
         :return:
         """
         result = self.gerrit.get(self.endpoint + "/stars.changes")
-        return [self.gerrit.changes.get(item.get("id")) for item in result]
+        return result
 
     def get_star_labels_from_change(self, id_):
         """
