@@ -23,8 +23,8 @@ def test_search_groups(gerrit_client):
 
 
 def test_get_group(gerrit_client):
-    from gerrit.utils.exceptions import NotFoundError
-    with pytest.raises(NotFoundError):
+    from gerrit.utils.exceptions import GroupNotFoundError
+    with pytest.raises(GroupNotFoundError):
         gerrit_client.groups.get(id_=1000000000)
 
     group_id = 613
@@ -32,7 +32,7 @@ def test_get_group(gerrit_client):
 
     assert type(group) == GerritGroup
 
-    assert str(group) == f"GerritGroup(name={group.name})"
+    assert str(group) == str(group.id)
 
     group_name = group.get_name()
     assert group_name == "Reviewers"
@@ -40,8 +40,8 @@ def test_get_group(gerrit_client):
     group_info = group.to_dict()
     assert group_info.get("name") == "Reviewers"
 
-    group_detail = gerrit_client.groups.get(group_id, detailed=True)
-    assert "members" in group_detail.to_dict()
+    group_detail = group.get_detail()
+    assert "members" in group_detail
 
     group_options = group.get_options()
     assert "visible_to_all" in group_options
@@ -52,7 +52,7 @@ def test_get_group(gerrit_client):
 
 @pytest.mark.xfail(reason="Request is not authorized")
 def test_create_group(gerrit_client):
-    # from gerrit.utils.exceptions import GroupAlreadyExistsError
+    from gerrit.utils.exceptions import GroupAlreadyExistsError
     input_ = {
         "description": "contains all committers for MyProject2",
         "visible_to_all": 'true',
@@ -60,8 +60,8 @@ def test_create_group(gerrit_client):
         "owner_id": "af01a8cb8cbd8ee7be072b98b1ee882867c0cf06"
     }
     group_name = "Reviewers"
-    # with pytest.raises(GroupAlreadyExistsError):
-    #     gerrit_client.groups.create(group_name, input_)
+    with pytest.raises(GroupAlreadyExistsError):
+        gerrit_client.groups.create(group_name, input_)
 
     group = gerrit_client.groups.create('My-Project2-Committers', input_)
     assert group.name == "My-Project2-Committers"
@@ -80,9 +80,9 @@ def test_add_group_member(gerrit_client):
     group = gerrit_client.groups.get(group_id)
 
     account_id = 16
-    # from gerrit.utils.exceptions import GroupMemberAlreadyExistsError
-    # with pytest.raises(GroupMemberAlreadyExistsError):
-    #     group.members.add(account_id)
+    from gerrit.utils.exceptions import GroupMemberAlreadyExistsError
+    with pytest.raises(GroupMemberAlreadyExistsError):
+        group.members.add(account_id)
 
     user = gerrit_client.accounts.get(account="shijl0925")
     account_id = user.account_id
@@ -96,14 +96,14 @@ def test_group_member(gerrit_client):
 
     account_id = 16
     member = group.members.get(account_id)
-    assert str(member) == f"GerritAccount(username={member.username})"
+    assert str(member) == str(account_id)
 
     result = member.to_dict()
     assert "_account_id" in result
 
-    from gerrit.utils.exceptions import NotFoundError
-    with pytest.raises(NotFoundError):
-        group.members.get(username=0)
+    from gerrit.utils.exceptions import GroupMemberNotFoundError
+    with pytest.raises(GroupMemberNotFoundError):
+        group.members.get(account=0)
 
 
 @pytest.mark.xfail(reason="Request is not authorized")
@@ -123,4 +123,4 @@ def test_group_subgroups(gerrit_client):
 
     subgroup_id = "3bff52be902fb279c5e495462a68b701e9bd5889"
     subgroup = group.subgroup.get(subgroup_id)
-    assert str(subgroup) == f"GerritGroup(name={subgroup.name})"
+    assert str(subgroup) == subgroup_id
