@@ -29,7 +29,6 @@ data = [
     },
 ]
 
-
 @pytest.mark.parametrize('is_all, limit, skip, pattern_dispatcher, project_type, description, branch, state',
                          [(False, 25, 0, None, None, False, None, "ACTIVE"),
                           (False, 25, 25, None, None, False, None, "ACTIVE"),
@@ -65,8 +64,8 @@ def test_search_projects(gerrit_client, query):
 @pytest.mark.parametrize('gerrit_object', data, indirect=True)
 def test_get_project(gerrit_client, gerrit_object):
     from gerrit.projects.project import GerritProject
-    from gerrit.utils.exceptions import NotFoundError
-    with pytest.raises(NotFoundError):
+    from gerrit.utils.exceptions import ProjectNotFoundError
+    with pytest.raises(ProjectNotFoundError):
         gerrit_client.projects.get(name="test-project0000000")
 
     project_name = gerrit_object["project_name"]
@@ -82,7 +81,8 @@ def test_get_project(gerrit_client, gerrit_object):
     assert all([hasattr(project, attr) for attr in attrs])
 
     project_id = project.id
-    assert str(project) == f"GerritProject(id={project_id})"
+    assert str(project) == f"{project_id}"
+    assert repr(project) == f"<gerrit.projects.project.GerritProject {project_id}>"
 
     project_info = project.to_dict()
     assert project_info.get("name") == project_name
@@ -91,7 +91,7 @@ def test_get_project(gerrit_client, gerrit_object):
     assert project.name == project_name
 
     assert project != gerrit_client.projects.get(name="LineageOS/android_art")
-    assert project != gerrit_client.accounts.get(username="shijl0925")
+    assert project != gerrit_client.accounts.get(account="shijl0925")
 
 
 @pytest.mark.parametrize('gerrit_object', data, indirect=True)
@@ -116,7 +116,7 @@ def test_get_project_parent(gerrit_client, project_name, expected):
                          [("LineageOS/android", "refs/heads/master")])
 def test_get_project_head(gerrit_client, project_name, expected):
     project = gerrit_client.projects.get(name=project_name)
-    HEAD = project.get_HEAD()
+    HEAD = project.get_head()
     assert HEAD == expected
 
 
@@ -140,7 +140,7 @@ def test_delete_project_description(gerrit_client):
 
 @pytest.mark.xfail(reason="Request is not authorized")
 def test_create_project(gerrit_client):
-    # from gerrit.utils.exceptions import ProjectAlreadyExistsError
+    from gerrit.utils.exceptions import ProjectAlreadyExistsError
     input_ = {
         "description": "This is a demo project.",
         "submit_type": "INHERIT",
@@ -149,8 +149,8 @@ def test_create_project(gerrit_client):
         ]
     }
     project_name = "LineageOS/android"  # "git-repo"
-    # with pytest.raises(ProjectAlreadyExistsError):
-    #     gerrit_client.projects.create(project_name, input_)
+    with pytest.raises(ProjectAlreadyExistsError):
+        gerrit_client.projects.create(project_name, input_)
 
     project = gerrit_client.projects.create('MyProject', input_)
     assert project.name == "MyProject"
@@ -180,15 +180,14 @@ def test_project_branches(gerrit_client, gerrit_object):
     branches = project.branches.list()
     assert len(branches) > 0
 
-    from gerrit.utils.exceptions import NotFoundError
-    with pytest.raises(NotFoundError):
+    from gerrit.utils.exceptions import BranchNotFoundError
+    with pytest.raises(BranchNotFoundError):
         project.branches.get(name="TEST-BRANCH")
 
     branch_name = gerrit_object["branch"]
     branch = project.branches.get(name=branch_name)
     assert branch.name == branch_name
-    logger.debug(str(branch))
-    assert str(branch) == f"GerritProjectBranch(ref=refs/heads/{branch_name})"
+    assert str(branch) == f"{branch_name}"
 
     master_info = branch.to_dict()
     assert master_info.get("ref") == f"refs/heads/{branch_name}"
@@ -197,6 +196,9 @@ def test_project_branches(gerrit_client, gerrit_object):
     file = branch.get_file_content(file=file_name)
     assert len(file) > 0
 
+    file = branch.get_file_content(file=file_name, decode=True)
+    assert len(file) > 0
+
 
 def test_project_branch_is_mergeable(gerrit_client):
     project_name = "LineageOS/android"  # "git-repo"
@@ -210,8 +212,8 @@ def test_project_branch_is_mergeable(gerrit_client):
     res = branch.is_mergeable(input_)
     assert "mergeable" in res.keys()
 
-    from gerrit.utils.exceptions import ValidationError
-    with pytest.raises(ValidationError):
+    from gerrit.utils.exceptions import BranchNotFoundError
+    with pytest.raises(BranchNotFoundError):
         input_ = {
             'source': 'lineage-19.2',
             'strategy': 'recursive'
@@ -221,15 +223,15 @@ def test_project_branch_is_mergeable(gerrit_client):
 
 @pytest.mark.xfail(reason="Request is not authorized")
 def test_create_project_branch(gerrit_client):
-    # from gerrit.utils.exceptions import BranchAlreadyExistsError
+    from gerrit.utils.exceptions import BranchAlreadyExistsError
     input_ = {
         'revision': '1b16713d0ca30ecc9f6f3ac78554d57b5d4fa467'
     }
     project_name = "LineageOS/android"  # "git-repo"
     project = gerrit_client.projects.get(project_name)
 
-    # with pytest.raises(BranchAlreadyExistsError):
-    #     project.branches.create('lineage-20.0', input_)
+    with pytest.raises(BranchAlreadyExistsError):
+        project.branches.create('lineage-20.0', input_)
 
     new_branch = project.branches.create('stable', input_)
     assert new_branch.name == "stable"
@@ -249,14 +251,14 @@ def test_project_tags(gerrit_client, gerrit_object):
     tags = project.tags.list()
     assert len(tags) > 0
 
-    from gerrit.utils.exceptions import NotFoundError
-    with pytest.raises(NotFoundError):
+    from gerrit.utils.exceptions import TagNotFoundError
+    with pytest.raises(TagNotFoundError):
         project.tags.get(name="TEST-TAG")
 
     tag_name = gerrit_object["tag"]
     tag = project.tags.get(name=tag_name)
     assert tag.name == tag_name
-    assert str(tag) == f"GerritProjectTag(ref=refs/tags/{tag_name})"
+    assert str(tag) == f"{tag_name}"
 
     tag_info = tag.to_dict()
     assert tag_info.get("ref") == f"refs/tags/{tag_name}"
@@ -264,16 +266,16 @@ def test_project_tags(gerrit_client, gerrit_object):
 
 @pytest.mark.xfail(reason="Request is not authorized")
 def test_create_project_tag(gerrit_client):
-    # from gerrit.utils.exceptions import TagAlreadyExistsError
+    from gerrit.utils.exceptions import TagAlreadyExistsError
     input_ = {
         "message": "annotation",
         'revision': '8351e4f8077fa038ea3ecbf60925581c8c40ccc4'
     }
     project_name = "LineageOS/android"  # "git-repo"
     project = gerrit_client.projects.get(project_name)
-    #
-    # with pytest.raises(TagAlreadyExistsError):
-    #     project.tags.create('cm-10.2-M1', input_)
+
+    with pytest.raises(TagAlreadyExistsError):
+        project.tags.create('cm-10.2-M1', input_)
 
     new_branch = project.tags.create('cm-10.2', input_)
     assert new_branch.name == "cm-10.2"
@@ -293,11 +295,11 @@ def test_get_project_commit(gerrit_client):
     hash_ = "1b16713d0ca30ecc9f6f3ac78554d57b5d4fa467"
     commit = project.get_commit(hash_)
 
-    from gerrit.utils.exceptions import NotFoundError
-    with pytest.raises(NotFoundError):
+    from gerrit.utils.exceptions import CommitNotFoundError
+    with pytest.raises(CommitNotFoundError):
         project.get_commit(commit="00000000000000000000")
 
-    assert str(commit) == f"GerritProjectCommit(commit={hash_})"
+    assert str(commit) == f"{hash_}"
 
     detail = commit.to_dict()
     assert "author" in detail
@@ -314,6 +316,9 @@ def test_get_project_commit(gerrit_client):
     content = commit.get_file_content(file_name)
     assert len(content) > 0
 
+    content = commit.get_file_content(file_name, decode=True)
+    assert len(content) > 0
+
     assert file_name in commit.list_change_files()
 
 
